@@ -1100,11 +1100,11 @@ class PartitionDistributive(Distributive):
 
     def getMultipartData(self):
         """Get multipartition data"""
-        mulipartData = zip(self.multipartition.getPartitions(),
+        mulipartData = list(zip(self.multipartition.getPartitions(),
                            self.multipartition.getMountPoints(),
                            self.multipartition.getFileSystems(),
                            self.multipartition.getIsFormat(),
-                           self.multipartition.getPartitionTable())
+                           self.multipartition.getPartitionTable()))
         return mulipartData
 
     def convertToDirectory(self):
