@@ -540,7 +540,7 @@ class VariableOsInstallNetRouteData(NetHelper, TableVariable):
             if not x[1] in ("off", "dhcp")]
         route_data = []
         if staticInterface:
-            staticInterface, skipNet = zip(*staticInterface)
+            staticInterface, skipNet = list(zip(*staticInterface))
             return [[x[0],
                     x[1].get('via', ''),
                     x[1].get('dev', ''),
@@ -675,10 +675,10 @@ class VariableOsInstallNetRoute(NetHelper, ReadonlyVariable):
     """
 
     def performRouteData(self, performFunc):
-        routeMatrix = zip(self.Get('os_install_net_route_network'),
+        routeMatrix = list(zip(self.Get('os_install_net_route_network'),
                           self.Get('os_install_net_route_gw'),
                           self.Get('os_install_net_route_dev'),
-                          self.Get('os_install_net_route_src'))
+                          self.Get('os_install_net_route_src')))
         DEV, IP, CIDR, NET = 0, 1, 2, 1
         return [performFunc(x[DEV], x[NET], routeMatrix) for x 
             # ip and mask to ip/net
