@@ -21,7 +21,7 @@ from os import path
 from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
                                     TableVariable, PasswordError,
                                     DataVarsError, VariableInterface)
-from calculate.install.fs_manager import FileSystemManager
+from ..fs_manager import FileSystemManager
 from calculate.lib.utils.files import (readFile, getProgPath, process,
                                        readLinesFile, readFileEx)
 from calculate.lib.utils.common import (getPasswdUsers, getUserGroups,
@@ -121,7 +121,7 @@ class VariableOsFormatType(ReadonlyVariable):
 
     def get(self):
         """Filesystem format support by calcualte-install"""
-        return FileSystemManager.supportFS.keys()
+        return list(FileSystemManager.supportFS.keys())
 
 
 class VariableOsFormatUse(ReadonlyVariable):
@@ -141,7 +141,7 @@ class VariableOsFormatUse(ReadonlyVariable):
         return "no"
 
     def get(self):
-        return map(self.checkFunc, self.Get('os_format_type'))
+        return [self.checkFunc(x) for x in self.Get('os_format_type')]
 
 
 class VariableClMigrateRootPwdPlain(GrubHelper, UserHelper, Variable):
@@ -194,10 +194,9 @@ class VariableClMigrateRootShadowPwd(ReadonlyVariable):
     содержит пустую строку
     """
     def get(self):
-        rootPasswd = map(lambda x: x[1],
-                         filter("root".__eq__,
-                                map(lambda x: x.split(':')[0:2],
-                                    readLinesFile('/etc/shadow'))))
+        rootPasswd = [x[1] for x 
+                in [y.split(':')[0:2] for y in readLinesFile('/etc/shadow')] 
+            if "root".__eq__(x)]
         if rootPasswd:
             rootPasswd = rootPasswd[0]
         else:
@@ -419,7 +418,7 @@ class VariableClMigrateAdmin(UserHelper, Variable):
                 for x in self.Get('cl_migrate_user')]
 
     def set(self, value):
-        return map(lambda x: x if x else self.default_value, value)
+        return [x if x else self.default_value for x in value]
 
 
 class VariableOsAvailableGroups(ReadonlyVariable):
@@ -476,8 +475,7 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
                 yield value
 
     def set(self, value):
-        value = map(lambda x: sorted(list(set(self.process_groups(x)))),
-                    value)
+        value = [sorted(list(set(self.process_groups(x)))) for x in value]
         return value
 
     def getPrimaryGroup(self, username):
@@ -491,11 +489,9 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
         User groups
         """
         passwdList = getPasswdUsers()
-        return map(lambda x: sorted(self.getPrimaryGroup(x) +
-                              (getUserGroups(x)
-                               if x in passwdList else
-                               self.getDefaultGroups())),
-                   self.Get('cl_migrate_user'))
+        return [sorted(self.getPrimaryGroup(x) + (getUserGroups(x)
+                if x in passwdList else self.getDefaultGroups())) for x 
+                in self.Get('cl_migrate_user')]
 
     def choice(self):
         """
@@ -525,15 +521,13 @@ class VariableClMigrateUserPwd(UserHelper, Variable):
             if migrateusers:
                 lenData = 9
                 with open(fileName) as f:
-                    shadowData = filter(lambda x: len(x) == lenData,
-                                        map(lambda x: x.rstrip().split(":"), f))
-                shadowData = filter(lambda x: x[0] in migrateusers, shadowData)
-                shadowData = map(lambda x: (x[0], x[1]), shadowData)
-                shadowUsers = map(lambda x: x[0], shadowData)
+                    shadowData = [x for x in [y.rstrip().split(":") for y in f] if len(x) == lenData]
+                shadowData = [x for x in shadowData if x[0] in migrateusers]
+                shadowData = [(x[0], x[1]) for x in shadowData]
+                shadowUsers = [x[0] for x in shadowData]
                 for userName in migrateusers:
                     if userName in shadowUsers:
-                        userData = filter(lambda x: x[0] == userName,
-                                          shadowData)
+                        userData = [x for x in shadowData if x[0] == userName]
                         hashPwd = userData[0][1]
                         if (sha256_crypt.identify(hashPwd) and
                             sha256_crypt.verify("guest", hashPwd)):
@@ -559,8 +553,7 @@ class VariableClMigrateUserPwd(UserHelper, Variable):
         """
         shadow_hash = get_shadow_hash()
 
-        return map(lambda x: x if shadow_hash.identify(x) or not x else \
-            shadow_hash.hash(x), value)
+        return [x if shadow_hash.identify(x) or not x else shadow_hash.hash(x) for x in value]
 
 
 class VariableClAutologin(UserHelper, Variable):
@@ -587,8 +580,8 @@ class VariableClAutologin(UserHelper, Variable):
         if (not cmdDomainSet and
                     self.Get('os_install_root_type') == "livecd") or \
                         self.Get('os_install_linux_shortname') == "CMC":
-            nonRootUsers = filter(lambda x: x != "root",
-                                  self.Get('cl_migrate_user'))
+
+            nonRootUsers = [x for x in self.Get('cl_migrate_user') if x != "root"]
             if nonRootUsers:
                 return nonRootUsers[0]
         else:
@@ -716,14 +709,10 @@ class VariableOsNvidiaMask(ReadonlyVariable):
         category = "0300"
         vendor = "10de:"
         lsPciProg = getProgPath("/usr/sbin/lspci")
-        nvidiacards = filter(lambda x: " %s: " % category in x,
-                             process(lsPciProg, "-d", vendor, "-n"))
-        cardsid = \
-            map(lambda x: x.groups()[0],
-                filter(lambda x: x,
-                       map(lambda x: re.search(
-                           "[0-9a-fA-F]{4}:([0-9a-fA-F]{4})", x),
-                           nvidiacards)))
+        nvidiacards = [x for x in process(lsPciProg, "-d", vendor, "-n") 
+            if " %s: " % category in x]
+        cardsid = [x.groups()[0] for x 
+            in [re.search("[0-9a-fA-F]{4}:([0-9a-fA-F]{4})", y) for y in nvidiacards] if x]
         if not cardsid:
             return set()
         return set(cardsid)
@@ -838,9 +827,10 @@ class VariableOsGrub2Path(Variable):
             return grubInstall
         # find grub-install and check, that this is grub2-install (ver 1.99)
         grubInstall = getProgPath('/usr/sbin/grub-install', prefix=chroot_path)
-        if grubInstall and filter(lambda x: "1.99" in x or "2." in x,
-                                  process(chroot_cmd, chroot_path, 
-                                          grubInstall, '--version')):
+
+        if grubInstall and [x for x 
+                in process(chroot_cmd, chroot_path, grubInstall, '--version') 
+                if "1.99" in x or "2." in x]:
             return grubInstall
         return ""
 
